*This file loads and prepares the data 

************Combine datasets****************************************************

*Load macrohistory dataset
use "../data/JSTdataset_v101.dta", clear

*merge with new bank balance sheet data
merge 1:1 country year using "../data/liabilities_final.dta"
drop _merge

*add data on leverage of large banks
merge 1:1 country year using "../data/lev_large.dta"
drop _merge

*add Datastream market leverage
merge 1:1 country year using "../data/DS.dta"
drop _merge

*merge with Baron/Xiong bank index excess returns
merge 1:1 country year using "../data/BXreturns.dta"
drop if _merge==2
drop _merge

*merge with bank profits data
sort country year
merge 1:1 country year using "../data/profits.dta"
drop _merge


********************************************************************************
*Prepare data:
********************************************************************************
sort country year
keep if year<=2015 & year>=1870

****** Creat ccode and first sort 
capture drop ccode
egen ccode = group(iso)
sort ccode year
tsset ccode year, yearly

****** Basic data  

gen lrgdp   = log(rgdpbarro)		// real GDP index from Barro
gen lcpi    = log(cpi)				// CPI
gen cay		= ca/gdp				// Current Account over GDP ratio
gen lpop    = log(pop)				// log Population for per capita growth
gen ltloans = log(tloans)			// Total loans to non-financial sector
gen rprv  	= ltloans - lcpi - lpop	// log real pc private loans per capita
gen riy 	= iy*rgdpbarro			// real pc investment
gen lriy 	= log(riy)				// log real investment
gen dlrgdp  = 100*d.lrgdp			// Annual real pc GDP growth in %
gen dlriy	= 100*d.lriy			// Annual real pc investment growth in %
gen dlcpi   = 100*d.lcpi			// Annual inflation in %
replace cay = 100*cay				// Current account ratio

gen lrstocks=log(stocks/cpi)		// real stock price index
gen lrhouses=log(hpnom/cpi)			// real HP index

*******Wars
gen war=0
replace war = 1 if year>=1914 & year<=1919
replace war = 1 if year>=1939 & year<=1947

*********Crisis, peaks and deposit insurance dating*****************************

do "../auxprograms/peak_dummies.do"

do "../auxprograms/BVXcrisis.do"

do "../auxprograms/DI_definitions.do"

do "../auxprograms/JSTcrisis_update.do"

*********************** Define balance sheet variables here ********************
gen loansgdp=tloans/gdp								// JST series of credit to GDP
gen liagdp=totlia/gdp								// Bank assets/liabilities to GDP
gen dloansgdp3=loansgdp-l3.loansgdp					// for BX2017 exercise

*bank balance sheet ratios
gen lev=(totcap/totlia)								// capital ratio measure
gen deposit=(totdep/totlia)							// share of deposits
gen noncore = (totothlia/(totothlia+totdep))		// share of noncore funding in debt 
gen ltd=(totloans/totdep) 							// Loan to deposit ratio



********************************************************************************
*Return and market data
********************************************************************************
*gen excess return
gen index_return=ln(1+eq_tr-stir/100)

*Market leverage ratio= price-to-book x book leverage ratio 
gen marketlev=BK_BP*lev

*as a risk control use broad index returns when no data from Baron and Xiong (2017) available
gen bank_return=bxreturns
replace bank_return=index_return if bank_return==.


********************************************************************************
*More transformations, changes, lags and volatilities
********************************************************************************
*Do not include German hyperinflation data 
local inflation lev noncore ltd lev_large index_return
foreach v of local inflation{
replace `v'=. if iso=="DEU" & year >1914 & year<=1923
}

xtset ccode year

local lags loansgdp liagdp lev deposit noncore ltd  ///
lrhouses lrstocks dlrgdp dlcpi dlriy stir ltrate cay ///
tloans bank_return marketlev BK_BP lev_large 

*gen first difference (exclude war-time changes)
foreach var of local lags{
gen d`var'=d.`var' if war==0
}	

*gen lagged variables
foreach var of local lags{
gen `var'_1=l.`var'
}

*5-year average changes: conditional on 5 changes observed 
foreach var of local lags{
tsegen d`var'5 = rowmean(L(1/5).d`var', 5)
}

*5-year average levels: conditional on 5 lags observed
foreach var of local lags{
tsegen `var'5 = rowmean(L(1/5).`var', 5)
}

*generate 5 year standard deviation conditional on 5 lags observed
local vol dlrgdp dlcpi stir dlrstocks dlrhouses dloansgdp
foreach var of local vol{
tsegen vol_`var'_5=rowsd(L(1/5).`var', 5)
}

********************************************************************************
*label important variables
label variable dlev5 "$\Delta_5$ Capital ratio"
label variable dltd5 "$\Delta_5$ LtD"
label variable dnoncore5 "$\Delta_5$ Non-core ratio"
label variable dliagdp5 "$\Delta_5$ Assets/GDP"
label variable dloansgdp5 "$\Delta_5$ Loans/GDP"
label variable lev_1 "Capital ratio"
label variable ltd_1 "LtD ratio"
label variable noncore_1 "Non-core ratio"
label variable marketlev_1 "Market-based capital ratio"
label variable dmarketlev5 "$\Delta_5$ Market-based capital ratio"

********************************************************************************
*Period effects
********************************************************************************

*gen decade FE
gen dec = year/10
gen decade = floor(dec)
tab decade, gen(dec_dum)

*gen country x decade FE
egen cdfe=group(iso decade)
tab cdfe, gen(cdfe_dum)

* force sort tsset again
sort ccode year
tsset ccode year, yearly

*gen country and year FEs 
tab iso, gen(ccode)
tab year, gen(yr)



