
preserve

keep if country=="Italy" & year>=1890 & year<=1973
keep year lev crisisJST

save "../data/ItalyAggregate.dta", replace

use "../data/Italy.dta", clear

*generate variables according to data paper
gen dep=voce3200/voce9995
gen cap=voce3000/voce9995
gen year=Anno

*do not consider data points where capital ratio is 0
drop if cap==0
drop if cap==.

*gen aggregates
bysort year: egen total=sum(voce9995) 
bysort year: egen totalcap=sum(voce3000) 

*exclude banks with market share less than 0.1%
gen ind_share=voce9995/total
drop if ind_share<=0.001


*keep joint stock banks and savings banks; cooperative banks were only sampled every 5 years
keep if Categoria=="SOC" | Categoria=="CRO"

xtset Id_Banca year

*keep if banks are more than 5 years in sample
bys Id_Banca: gen nyear=[_N]
keep if nyear>5

gen pcap5=0
gen pcap10=0
gen pcap25=0
gen pcap50=0

gen p5cap=.
gen p10cap=.
gen p25cap=.
gen p50cap=.

*generate capital ratio percentiles by year
forvalues year=1890/1970{
sum cap if year==`year', d
replace pcap5=1 if cap<r(p5) & year==`year'
replace p5cap=r(p5) if year==`year'
replace pcap10=1 if cap<r(p10) & year==`year'
replace p10cap=r(p10) if year==`year'
replace pcap25=1 if cap<r(p25) & year==`year'
replace p25cap=r(p25) if  year==`year'
replace pcap50=1 if cap<r(p50) & year==`year'
replace p50cap=r(p50) if year==`year'
}

local percentiles 5 10 25 50

*generate aggregate capital ratio
gen agg=totalcap/total

* generate share of percentiles
foreach p in `percentiles'{
bysort year: egen total`p'=sum(voce9995) if pcap`p'==1 
gen assetshare`p'=total`p'/total
bysort year: egen share`p'=mean(assetshare`p')
}

twoway line share5 share10 share25 share50 year

keep year share5 share10 share25 share50 p5cap p10cap p25cap p50cap agg 

*keep only one observation per year
duplicates drop

*merge with aggregate series data for Italy
merge 1:1 year using "../data/ItalyAggregate.dta"

twoway line agg lev year


label var p5cap "5th percentile"
label var p10cap "10th percentile"
label var p25cap "25th percentile"
label var p50cap "Median"
label var lev "Aggregate"

* rescaled variables, in %
gen lev_r  =100*lev
gen p5cap_r  =100*p5cap
gen p10cap_r =100*p10cap
gen p25cap_r =100*p25cap
gen p50cap_r =100*p50cap

label var p5cap_r "5th percentile"
label var p10cap_r "10th percentile"
label var p25cap_r "25th percentile"
label var p50cap_r "Median"
label var lev_r "Aggregate ratio"


twoway (line p5cap_r p10cap_r p25cap_r lev_r year , lc(red orange green blue)  lp(dot dash longdash solid) lw(thick..) ) /// 
	if year<=1970 & year>=1890, xtitle("") ///
	legend(pos(1) ring(0) col(1) region(ls(none)) order(4 3 2 1) ) /// legend(off) ///
	xscale(r(1890 1975)) xlabel(1890 (10) 1970) xline(1893 1907 1921 1930 1935, lcolor(gs7) lwidth(medthick)) scale(.9) ///
	name(x,replace) title("") ytitle("Capital ratio (%)") 

graph display, ysize(3) xsize(6) scale(1.25)

graph export "../graphs/Figure_A7.pdf", replace
graph export "../graphs/Figure_A7.eps", replace


********************************************************************************
*Probit
********************************************************************************
tsset year
sort year

*Lag capital ratios by one year
sort year

local percentiles p5cap p10cap p25cap p50cap lev

foreach v of local percentiles{
gen `v'_1=l.`v'
}

cap drop war
gen war=0
replace war = 1 if year>=1914 & year<=1919 
replace war = 1 if year>=1939 & year<=1947


*Probit
probit crisisJST p5cap_1 if war==0, vce(robust)
gen xsample=e(sample)
predict temp if xsample==1, xb
	margins, dydx(_all) at((mean) _all) post
	roctab crisisJST temp
	estadd scalar AUC = r(area)
	estadd scalar se = r(se)
	eststo p5
	drop temp
	
probit crisisJST p10cap_1 if xsample==1, vce(robust)
predict temp if xsample==1, xb
	margins, dydx(_all) at((mean) _all) post
	roctab crisisJST temp
	estadd scalar AUC = r(area)
	estadd scalar se = r(se)
	eststo p10
	drop temp
	
probit crisisJST p25cap_1 if xsample==1, vce(robust)
predict temp if xsample==1, xb
	margins, dydx(_all) at((mean) _all) post
	roctab crisisJST temp
	estadd scalar AUC = r(area)
	estadd scalar se = r(se)
	eststo p25
	drop temp
	
probit crisisJST lev_1 if xsample==1, vce(robust)
predict temp if xsample==1, xb
	margins, dydx(_all) at((mean) _all) post
	roctab crisisJST temp
	estadd scalar AUC = r(area)
	estadd scalar se = r(se)
	eststo lev
	drop temp
	
label variable p25cap_1 "Capital Ratio"
label variable p10cap_1 "Capital Ratio"
label variable p5cap_1 "Capital Ratio"
label variable lev_1 "Capital Ratio"


*Save Table
esttab p5 p10 p25 lev ///
	using "../tables/Table_A10.tex", replace label ///
	mtitles("5th" "10th" "25th" "Agg") ///
	keep(p5cap_1 p10cap_1 p25cap_1 lev_1) scalars(AUC se) margin se nonotes wrap eqlabels(none) ///
	b(2) se(2) sfmt(2) obslast star(* 0.10 ** 0.05 *** 0.01)


graph drop _all

restore
